==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/mixin/BlockModelGeneratorsAccessor.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.mixin;

import net.minecraft.class_2248;
import net.minecraft.class_2960;
import net.minecraft.class_4910;
import net.minecraft.class_4917;
import net.minecraft.class_4925;
import net.minecraft.class_4926;
import net.minecraft.class_4935;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.gen.Invoker;

@Mixin(class_4910.class)
public interface BlockModelGeneratorsAccessor {
	@Invoker("createSlab")
	static class_4917 makeSlabState(class_2248 block, class_2960 bottomModel, class_2960 topModel, class_2960 doubleModel) {
		throw new IllegalStateException();
	}

	@Invoker("createStairs")
	static class_4917 makeStairState(class_2248 block, class_2960 innerModel, class_2960 straightModel, class_2960 outerModel) {
		throw new IllegalStateException();
	}

	@Invoker("createWall")
	static class_4917 makeWallState(class_2248 block, class_2960 postModel, class_2960 lowModel, class_2960 tallModel) {
		throw new IllegalStateException();
	}

	@Invoker("createFenceGate")
	static class_4917 makeFenceGateState(class_2248 block, class_2960 openModel, class_2960 closedModel, class_2960 openWallModel, class_2960 closedWallModel) {
		throw new IllegalStateException();
	}

	@Invoker("createFence")
	static class_4917 makeFenceState(class_2248 block, class_2960 postModel, class_2960 sideModel) {
		throw new IllegalStateException();
	}

	@Invoker("createAxisAlignedPillarBlock")
	static class_4917 createAxisAlignedPillarBlock(class_2248 block, class_2960 model) {
		throw new IllegalStateException();
	}

	@Invoker("createHorizontalFacingDispatch")
	static class_4926 horizontalDispatch() {
		throw new IllegalStateException();
	}

	@Invoker("createFacingDispatch")
	static class_4926 facingDispatch() {
		throw new IllegalStateException();
	}

	@Invoker("createRotatedVariants")
	static class_4935[] createRotatedVariants(class_2960 model) {
		throw new IllegalStateException();
	}

	@Invoker("createRotatedVariant")
	static class_4925 createRotatedVariant(class_2248 block, class_2960 model, class_2960 mirroredModel) {
		throw new IllegalStateException();
	}
}

==> Botania-1.20.1-451-FABRIC-20260119.100843-40-sources.jar: vazkii/botania/mixin/BlockModelGeneratorsAccessor.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.mixin;

import net.minecraft.class_2248;
import net.minecraft.class_2960;
import net.minecraft.class_4910;
import net.minecraft.class_4917;
import net.minecraft.class_4926;
import net.minecraft.class_4935;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.gen.Invoker;

@Mixin(class_4910.class)
public interface BlockModelGeneratorsAccessor {
	@Invoker("createSlab")
	static class_4917 makeSlabState(class_2248 block, class_2960 bottomModel, class_2960 topModel, class_2960 doubleModel) {
		throw new IllegalStateException();
	}

	@Invoker("createFenceGate")
	static class_4917 makeFenceGateState(class_2248 block, class_2960 openModel, class_2960 closedModel, class_2960 openWallModel, class_2960 closedWallModel, boolean uvLock) {
		throw new IllegalStateException();
	}

	@Invoker("createFence")
	static class_4917 makeFenceState(class_2248 block, class_2960 postModel, class_2960 sideModel) {
		throw new IllegalStateException();
	}

	@Invoker("createAxisAlignedPillarBlock")
	static class_4917 createAxisAlignedPillarBlock(class_2248 block, class_2960 model) {
		throw new IllegalStateException();
	}

	@Invoker("createHorizontalFacingDispatch")
	static class_4926 horizontalDispatch() {
		throw new IllegalStateException();
	}

	@Invoker("createFacingDispatch")
	static class_4926 facingDispatch() {
		throw new IllegalStateException();
	}

	@Invoker("createRotatedVariants")
	static class_4935[] createRotatedVariants(class_2960 model) {
		throw new IllegalStateException();
	}
}
